==> kdegraphics-3.2.3.tar.bz2: kdegraphics-3.2.3/ksvg/dom/SVGExternalResourcesRequired.h <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef SVGExternalResourcesRequired_H
#define SVGExternalResourcesRequired_H

namespace KSVG
{

class SVGAnimatedBoolean;
class SVGExternalResourcesRequiredImpl;
class SVGExternalResourcesRequired 
{ 
public:
	SVGExternalResourcesRequired(const SVGExternalResourcesRequired &other);
	SVGExternalResourcesRequired &operator=(const SVGExternalResourcesRequired &other);
	SVGExternalResourcesRequired(SVGExternalResourcesRequiredImpl *other);
	~SVGExternalResourcesRequired();

	SVGAnimatedBoolean externalResourcesRequired() const;

	// Internal! - NOT PART OF THE SVG SPECIFICATION
	SVGExternalResourcesRequiredImpl *handle() const { return impl; }

protected:
	SVGExternalResourcesRequired();

private:
	SVGExternalResourcesRequiredImpl *impl;
};

};

#endif

// vim:ts=4:noet

==> kdegraphics-3.5.9.tar.bz2: kdegraphics-3.5.9/ksvg/dom/SVGExternalResourcesRequired.h <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef SVGExternalResourcesRequired_H
#define SVGExternalResourcesRequired_H

namespace KSVG
{

class SVGAnimatedBoolean;
class SVGExternalResourcesRequiredImpl;
class SVGExternalResourcesRequired 
{ 
public:
	SVGExternalResourcesRequired(const SVGExternalResourcesRequired &other);
	SVGExternalResourcesRequired &operator=(const SVGExternalResourcesRequired &other);
	SVGExternalResourcesRequired(SVGExternalResourcesRequiredImpl *other);
	~SVGExternalResourcesRequired();

	SVGAnimatedBoolean externalResourcesRequired() const;

	// Internal! - NOT PART OF THE SVG SPECIFICATION
	SVGExternalResourcesRequiredImpl *handle() const { return impl; }

protected:
	SVGExternalResourcesRequired();

private:
	SVGExternalResourcesRequiredImpl *impl;
};

}

#endif

// vim:ts=4:noet
